Value

Struct Value 

pub struct Value { /* private fields */ }
Describes a value definition.

Implementations

Source

impl Value

pub fn defining_entity(&self) -> DefiningEntity

Get the defining entity

pub fn defining_op(&self) -> Option<Ptr<Operation>>

If the defining entity of this value is Operation, return it. Otherwise, return None.

pub fn defining_block(&self) -> Option<Ptr<BasicBlock>>

If the defining entity of this value is BasicBlock, return it. Otherwise, return None.

pub fn try_find_index(&self, ctx: &Context) -> Result<usize>

Find the (result / argument) index of this value in its defining entity. Returns Err if this value is not currently defined by its defining entity.

pub fn find_index(&self, ctx: &Context) -> usize

Find the (result / argument) index of this value in its defining entity. Panics if this value is not currently defined by its defining entity.

pub fn num_uses(&self, ctx: &Context) -> usize

How many uses does this definition have?

pub fn uses(&self, ctx: &Context) -> Vec<Use<Value>>

Get all uses of this value.

pub fn is_used(&self, ctx: &Context) -> bool

Does this definition have any Use?

pub fn replace_some_uses_with<P: Fn(&Context, &Use<Value>) -> bool>( &self, ctx: &Context, predicate: P, other: &Value, )

Replace uses of the underlying definition, that satisfy pred, with other.

pub fn replace_all_uses_with(&self, ctx: &Context, other: &Value)

Replace all uses of the underlying definition with other.

pub fn replace_use_with(&self, ctx: &Context, use: Use<Value>, other: &Value)

Replace the given use of this Value with other.

pub fn loc(&self, ctx: &Context) -> Location

Get this value’s location

pub fn set_type(&self, ctx: &Context, ty: Ptr<TypeObj>)

Set this value’s type.

pub fn get_defining_block(&self, ctx: &Context) -> Option<Ptr<BasicBlock>>

Get the defining block of this value.