pub struct Value { /* private fields */ }Expand description
Describes a value definition.
Implementations
Sourceimpl Value
impl Value
Sourcepub fn defining_entity(&self) -> DefiningEntity
pub fn defining_entity(&self) -> DefiningEntity
Get the defining entity
Sourcepub fn defining_op(&self) -> Option<Ptr<Operation>>
pub fn defining_op(&self) -> Option<Ptr<Operation>>
Sourcepub fn defining_block(&self) -> Option<Ptr<BasicBlock>>
pub fn defining_block(&self) -> Option<Ptr<BasicBlock>>
If the defining entity of this value is BasicBlock, return it. Otherwise, return None.
Sourcepub fn try_find_index(&self, ctx: &Context) -> Result<usize>
pub fn try_find_index(&self, ctx: &Context) -> Result<usize>
Find the (result / argument) index of this value in its defining entity. Returns Err if this value is not currently defined by its defining entity.
Sourcepub fn find_index(&self, ctx: &Context) -> usize
pub fn find_index(&self, ctx: &Context) -> usize
Find the (result / argument) index of this value in its defining entity. Panics if this value is not currently defined by its defining entity.
Sourcepub fn replace_some_uses_with<P: Fn(&Context, &Use<Value>) -> bool>(
&self,
ctx: &Context,
predicate: P,
other: &Value,
)
pub fn replace_some_uses_with<P: Fn(&Context, &Use<Value>) -> bool>( &self, ctx: &Context, predicate: P, other: &Value, )
Replace uses of the underlying definition, that satisfy pred, with other.
Sourcepub fn replace_all_uses_with(&self, ctx: &Context, other: &Value)
pub fn replace_all_uses_with(&self, ctx: &Context, other: &Value)
Replace all uses of the underlying definition with other.
Sourcepub fn replace_use_with(&self, ctx: &Context, use: Use<Value>, other: &Value)
pub fn replace_use_with(&self, ctx: &Context, use: Use<Value>, other: &Value)
Replace the given use of this Value with other.
Sourcepub fn get_defining_block(&self, ctx: &Context) -> Option<Ptr<BasicBlock>>
pub fn get_defining_block(&self, ctx: &Context) -> Option<Ptr<BasicBlock>>
Get the defining block of this value.